@@ -163,13 +163,54 @@ impl Server {
             .collect()
     }
 
+    /// Add torrent from url/magnetlink.
+    ///
+    /// If start is true, also start the added download.
+    pub fn load_torrent_url(&self, link: &str, start: bool) -> Result<i64> {
+        let load = if start {
+            "load.start_verbose"
+        } else {
+            "load.verbose"
+        };
+        let raw_response = Request::new(load)
+            .arg("")
+            .arg(link.to_string())
+            .call_url(self.endpoint())?;
+        <i64 as TryFromValue>::try_from_value(&raw_response)
+    }
+
+    /// Add torrent from torrent file contents.
+    ///
+    /// If start is true, also start the added download.
+    pub fn load_torrent_bytes(&self, contents: &[u8], start: bool) -> Result<i64> {
+        let load = if start {
+            "load.raw_start_verbose"
+        } else {
+            "load.raw_verbose"
+        };
+        let raw_response = Request::new(load)
+            .arg("")
+            .arg(contents.to_vec())
+            .call_url(self.endpoint())?;
+        <i64 as TryFromValue>::try_from_value(&raw_response)
+    }
+
     server_getter!(
         /// Get the IP address associated with this rtorrent instance.
         ip, "network.bind_address", String);
+    server_getter!(
+        /// Get the port(s) associated with this rtorrent instance.
+        port, "network.port_range", String);
     server_getter!(
         /// Get the hostname associated with this rtorrent instance.
         hostname, "system.hostname", String);
-
+    server_getter!(
+        /// Get the time in seconds since Unix Epoch when this rtorrent instance was started.
+        startup_time, "system.startup_time", i64);
+    server_getter!(
+        /// Exit rtorrent, informing trackers that we are going away and waiting some time for them
+        /// to acknowledge.
+        exit_rtorrent, "system.shutdown.normal", i64);
     server_getter!(
         /// Get the XMLRPC API version associated with this instance.
         api_version, "system.api_version", String);
